# This file contains material to replicate the analyses reported
# in Buhaug, Halvard; Kristian Skrede Gleditsch, Helge Holtermann, 
# Gudrun stby, and Andreas For Tollefsen. 
# "It's the Local Economy, Stupid! Geographic Wealth Dispersion 
# and Conflict Outbreak Location", Journal of Conflict Resolution, TBA
#
# Please direct all correspondence to Kristian Skrede Gleditsch, 
# Department of Government, University of Essex, ksg@essex.ac.uk

# This version: 3 Nov 2010 KSG


# Note: The full PRIO-GRID are very large and still under development, 
# please contact Andreas Tollefsen andreas@prio.no if you 
# are interested in a copy

# Contents: 
#
# bghoet_full.asc   Full version of PG data, with the various 
#                   restrictions based in the data (i.e., population 
#                   and landmass share)
#
# bghoet_153.asc    The random case control sample of the above data,
#                   with seed set to 153
#
# bghoet_nns.asc    Case control sample without new states experiencing 
#                   border changes over the period. 


# Set wording directory to folder with data
# (replace with your own directory)
setwd("C:\\work\\work17\\geoginc\\")


# Read case control data reported in analyses
jcrrep <- read.table("bghoet_153.asc",
    sep="\t",quote="",header=T,as.is=T)

# This replicates table 2

# Model 1, Table 2
mod1tab2 <- glm(conset ~ log(gcppc1),
    family=binomial(link=logit),data=jcrrep,na.action=na.omit)
summary(mod1tab2)

# Model 2, Table 2 
mod2tab2 <- glm(conset ~ log(gcppc1) + log(gdppc2),
    family=binomial(link=logit),data=jcrrep,na.action=na.omit)
summary(mod2tab2)

# Model 3, Table 2
mod3tab2 <- glm(conset ~ log(gcppc1) + pos + 
    neg + I(pos*ldc) + I(EXCLUDED==1) 
    + log(brdist_90+1) + log(capdist_90+1) + capcity
    + fr_perc + mt_perc
    + log(POPGPW1990) + I(nocell/1000),
    family=binomial(link=logit),data=jcrrep,na.action=na.omit)
summary(mod3tab2)

# Model 4, Table 3
mod4tab3 <- glm(conset ~ log(gcppc1) + pos + neg + I(pos*ldc) + I(EXCLUDED==1) 
        + log(brdist_90+1) + log(capdist_90+1) + capcity
        + fr_perc + mt_perc
        + log(POPGPW1990) + I(nocell/1000) + priorconf,
    family=binomial(link=logit),data=jcrrep,na.action=na.omit)
summary(mod4tab3)

# Read second case control sample, w/o new states
jcrrep2 <- read.table("bghoet_nns.asc",
    sep="\t",quote="",header=T,as.is=T)

# Model 5, Table 3
mod5tab3 <- glm(conset ~ log(gcppc1) + pos + neg + I(pos*ldc) + I(EXCLUDED==1) 
        + log(brdist_90+1) + log(capdist_90+1) + capcity
        + fr_perc + mt_perc
        + log(POPGPW1990) + I(nocell/1000),
    family=binomial(link=logit),data=jcrrep2,na.action=na.omit)
summary(mod5tab3)

# Model 6, Table 3
mod6tab3 <- glm(conset ~ log(ADJIMR) + pos + neg + I(pos*ldc) + I(EXCLUDED==1) 
        + log(brdist_90+1) + log(capdist_90+1) + capcity
        + fr_perc + mt_perc
        + log(POPGPW1990) + I(nocell/1000),
    family=binomial(link=logit),data=jcrrep,na.action=na.omit,
    subset=(ADJIMR!=-9999))
summary(mod6tab3)
